==> weather-icons-lite-1.0.0.tgz: package/README.md <==
# Weather Icons Light

## Weather Themed Icons and CSS

Weather Icons Lite is a collection of 57 weather themed icons, ready to be dropped right into [Bootstrap](http://www.getbootstrap.com), or any project that needs high quality weather based icons!

![Icon Preview](images/example.PNG)

## Basic Usage

The icons are displayed by using an `i` element and adding the base class `wi` and then the icon class you want, so for example, using Wunderground's 'wu' prefix and their 'partlycloudy' icon key. This would then look like `<i class="wi wi-wu-partlycloudy"></i>`.

To add a modifier, include the class you want after the icon name, which looks like `<i class="wi wi-wu-partlycloudy wi-flip-vertical"></i>`. You can flip, rotate, or add a fixed width. For further examples of how to apply different effects, see [Font Awsome](http://fontawesome.io/examples/).

## API Usage

This set includes companion CSS files for popular weather service API. Presently there are complete CSS mappings for Darksky, Open Weather Map and Weather Underground.

## Credits

The icon designs are originally by [Lukas Bischoff](http://www.twitter.com/artill). Additional Icon art & CSS by [Erik Flowers](http://www.helloerik.com).  
Weather-icons-lite, CSS update & Node-red compatibility changes by me - Paul Reed.

## Licensing

* Weather Icons licensed under [SIL OFL 1.1](http://scripts.sil.org/OFL)
* Code licensed under [MIT License](http://opensource.org/licenses/mit-license.html)
* Documentation licensed under [CC BY 3.0](http://creativecommons.org/licenses/by/3.0)

==> weather-icons-lite-1.1.0.tgz: package/README.md <==
# Weather Icons Light

## Weather Themed Icons and CSS

Weather Icons Lite is a collection of 57 weather themed icons, ready to be dropped right into [Bootstrap](http://www.getbootstrap.com), or any project that needs high quality weather based icons!

![Icon Preview](images/example.PNG)

## Basic Usage

The icons are displayed by using an `i` element and adding the base class `wi` and then the icon class you want, so for example, using [Wunderground's](https://www.wunderground.com/about/icons.asp) 'wu' prefix and their 'partlycloudy' icon key. This would then look like `<i class="wi wi-wu-partlycloudy"></i>`.  
The same format applies to [Darksky](https://darksky.net/dev/docs/faq#faq-api-features) & [Openweathermap](https://openweathermap.org/weather-conditions) icon feeds; `<i class="wi wi-darksky-clear-day"></i>` and `<i class="wi wi-owm-01d"></i>` respectively.

To add a modifier, include the class you want after the icon name, which looks like `<i class="wi wi-wu-partlycloudy wi-flip-vertical"></i>`. You can flip, rotate, or add a fixed width. For further examples of how to apply different effects, see [Font Awsome](http://fontawesome.io/examples/).

## API Usage

This set includes companion CSS files for popular weather service API. Presently there are complete CSS mappings for Darksky, Open Weather Map and Weather Underground.

## Credits

The icon designs are originally by [Lukas Bischoff](http://www.twitter.com/artill). Additional Icon art & CSS by [Erik Flowers](http://www.helloerik.com).  
Weather-icons-lite, CSS update & Node-red compatibility changes by me - Paul Reed.

## Licensing

* Weather Icons licensed under [SIL OFL 1.1](http://scripts.sil.org/OFL)
* Code licensed under [MIT License](http://opensource.org/licenses/mit-license.html)
* Documentation licensed under [CC BY 3.0](http://creativecommons.org/licenses/by/3.0)
